==> owncloud-8.1.0p2.tgz: owncloud/apps/encryption/l10n/tr.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Eksik kurtarma anahtarı parolası",
    "Please repeat the recovery key password" : "Lütfen kurtarma anahtarı parolasını yenileyin",
    "Repeated recovery key password does not match the provided recovery key password" : "Yenilenen kurtarma anahtarı parolası, belirtilen kurtarma anahtarı parolası ile eşleşmiyor",
    "Recovery key successfully enabled" : "Kurtarma anahtarı başarıyla etkinleştirildi",
    "Could not enable recovery key. Please check your recovery key password!" : "Kurtarma anahtarı etkinleştirilemedi. Lütfen kurtarma anahtarı parolanızı kontrol edin!",
    "Recovery key successfully disabled" : "Kurtarma anahtarı başarıyla devre dışı bırakıldı",
    "Could not disable recovery key. Please check your recovery key password!" : "Kurtarma anahtarı devre dışı bırakılamadı. Lütfen kurtarma anahtarı parolanızı kontrol edin!",
    "Missing parameters" : "Eksik parametreler",
    "Please provide the old recovery password" : "Lütfen eski kurtarma parolasını girin",
    "Please provide a new recovery password" : "Lütfen yeni bir kurtarma parolası girin",
    "Please repeat the new recovery password" : "Lütfen yeni kurtarma parolasını yenileyin",
    "Password successfully changed." : "Parola başarıyla değiştirildi.",
    "Could not change the password. Maybe the old password was not correct." : "Parola değiştirilemedi. Eski parolanız doğru olmayabilir.",
    "Recovery Key disabled" : "Kurtarma Anahtarı kapalı",
    "Recovery Key enabled" : "Kurtarma Anahtarı etkin",
    "Could not enable the recovery key, please try again or contact your administrator" : "Kurtarma anahtarını etkinleştirilemedi, tekrar deneyin ya da yöneticinize başvurun",
    "Could not update the private key password." : "Özel anahtar parolası güncellenemedi",
    "The old password was not correct, please try again." : "Eski parola doğru değil, lütfen yeniden deneyin.",
    "The current log-in password was not correct, please try again." : "Geçerli oturum parolası doğru değil, lütfen yeniden deneyin.",
    "Private key password successfully updated." : "Özel anahtar parolası başarıyla güncellendi.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Eski şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine taşımanız gerekli. Lütfen 'occ encryption:migrate' çalıştırın veya yöneticinize danışın",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Şifreleme Uygulaması için geçersiz özel anahtar. Lütfen şifreli dosyalarınıza erişimi tekrar kazanabilmek için kişisel ayarlarınızdan özel anahtar parolanızı güncelleyin.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Şifreleme Uygulaması etkin ancak anahtarlarınız başlatılmamış. Lütfen oturumu kapatıp yeniden açın",
    "Encryption App is enabled and ready" : "Şifreleme Uygulaması etkin ve hazır",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Bu dosya muhtemelen bir paylaşılan dosya olduğundan şifrelemesi kaldırılamıyor. Lütfen dosyayı sizinle bir daha paylaşması için dosya sahibi ile iletişime geçin.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Bu dosya muhtemelen bir paylaşılan dosya olduğundan okunamıyor. Lütfen dosyayı sizinle bir daha paylaşması için dosya sahibi ile iletişime geçin.",
    "Enable recovery key" : "Kurtarma anahtarını etkinleştir",
    "Disable recovery key" : "Kurtarma anahtarını devre dışı bırak",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kurtarma anahtarı, dosyaların şifrelenmesi için daha fazla \nşifreleme sunar. Bu kullanıcının dosyasının şifresini unuttuğunda kurtarmasına imkan verir.",
    "Recovery key password" : "Kurtarma anahtarı parolası",
    "Repeat recovery key password" : "Kurtarma anahtarı parolasını yineleyin",
    "Change recovery key password:" : "Kurtarma anahtarı parolasını değiştir:",
    "Old recovery key password" : "Eski kurtarma anahtarı parolası",
    "New recovery key password" : "Yeni kurtarma anahtarı parolası",
    "Repeat new recovery key password" : "Yeni kurtarma anahtarı parolasını yineleyin",
    "Change Password" : "Parola Değiştir",
    "ownCloud basic encryption module" : "ownCloud basit şifreleme modülü",
    "Your private key password no longer matches your log-in password." : "Özel anahtar parolanız artık oturum açma parolanız ile eşleşmiyor.",
    "Set your old private key password to your current log-in password:" : "Eski özel anahtar parolanızı, geçerli oturum açma parolanız olarak ayarlayın:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Eğer eski parolanızı hatırlamıyorsanız, yöneticinizden dosyalarınızı kurtarmasını talep edebilirsiniz.",
    "Old log-in password" : "Eski oturum açma parolası",
    "Current log-in password" : "Geçerli oturum açma parolası",
    "Update Private Key Password" : "Özel Anahtar Parolasını Güncelle",
    "Enable password recovery:" : "Parola kurtarmayı etkinleştir:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Bu seçeneği etkinleştirmek, parola kaybı durumunda şifrelenmiş dosyalarınıza erişimi yeniden kazanmanızı sağlayacaktır",
    "Enabled" : "Etkin",
    "Disabled" : "Devre Dışı"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/encryption/l10n/tr.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Eksik kurtarma anahtarı parolası",
    "Please repeat the recovery key password" : "Lütfen kurtarma anahtarı parolasını yenileyin",
    "Repeated recovery key password does not match the provided recovery key password" : "Yenilenen kurtarma anahtarı parolası, belirtilen kurtarma anahtarı parolası ile eşleşmiyor",
    "Recovery key successfully enabled" : "Kurtarma anahtarı başarıyla etkinleştirildi",
    "Could not enable recovery key. Please check your recovery key password!" : "Kurtarma anahtarı etkinleştirilemedi. Lütfen kurtarma anahtarı parolanızı kontrol edin!",
    "Recovery key successfully disabled" : "Kurtarma anahtarı başarıyla devre dışı bırakıldı",
    "Could not disable recovery key. Please check your recovery key password!" : "Kurtarma anahtarı devre dışı bırakılamadı. Lütfen kurtarma anahtarı parolanızı kontrol edin!",
    "Missing parameters" : "Eksik parametreler",
    "Please provide the old recovery password" : "Lütfen eski kurtarma parolasını girin",
    "Please provide a new recovery password" : "Lütfen yeni bir kurtarma parolası girin",
    "Please repeat the new recovery password" : "Lütfen yeni kurtarma parolasını yenileyin",
    "Password successfully changed." : "Parola başarıyla değiştirildi.",
    "Could not change the password. Maybe the old password was not correct." : "Parola değiştirilemedi. Eski parolanız doğru olmayabilir.",
    "Recovery Key disabled" : "Kurtarma Anahtarı kapalı",
    "Recovery Key enabled" : "Kurtarma Anahtarı etkin",
    "Could not enable the recovery key, please try again or contact your administrator" : "Kurtarma anahtarını etkinleştirilemedi, tekrar deneyin ya da yöneticinize başvurun",
    "Could not update the private key password." : "Özel anahtar parolası güncellenemedi",
    "The old password was not correct, please try again." : "Eski parola doğru değil, lütfen yeniden deneyin.",
    "The current log-in password was not correct, please try again." : "Geçerli oturum parolası doğru değil, lütfen yeniden deneyin.",
    "Private key password successfully updated." : "Özel anahtar parolası başarıyla güncellendi.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Eski şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine taşımanız gerekli. Lütfen 'occ encryption:migrate' çalıştırın veya yöneticinize danışın",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Şifreleme Uygulaması için geçersiz özel anahtar. Lütfen şifreli dosyalarınıza erişimi tekrar kazanabilmek için kişisel ayarlarınızdan özel anahtar parolanızı güncelleyin.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Şifreleme Uygulaması etkin ancak anahtarlarınız başlatılmamış. Lütfen oturumu kapatıp yeniden açın",
    "Encryption App is enabled and ready" : "Şifreleme Uygulaması etkin ve hazır",
    "one-time password for server-side-encryption" : "sunucu tarafında şifleme için tek kullanımlık parola",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Bu dosya muhtemelen bir paylaşılan dosya olduğundan şifrelemesi kaldırılamıyor. Lütfen dosyayı sizinle bir daha paylaşması için dosya sahibi ile iletişime geçin.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Bu dosya muhtemelen bir paylaşılan dosya olduğundan okunamıyor. Lütfen dosyayı sizinle bir daha paylaşması için dosya sahibi ile iletişime geçin.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Selam,\n\nSistem yöneticisi sunucu tarafında şifrelemeyi etkinleştirdi. Dosyalarınız '%s' parolası kullanılarak şifrelendi.\n\nLütfen web arayüzünde oturum açın ve kişisel ayarlarınızdan 'ownCloud temel şifreleme modülü'ne giderek 'eski oturum parolası' alanına bu parolayı girdikten sonra şifreleme parolanızı ve mevcut oturum açma parolanızı güncelleyin.\n\n",
    "The share will expire on %s." : "Bu paylaşım %s tarihinde sona erecek.",
    "Cheers!" : "Hoşçakalın!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Selam,<br><br>Sistem yöneticisi sunucu tarafında şifrelemeyi etkinleştirdi. Dosyalarınız <strong>%s</strong> parolası kullanılarak şifrelendi.<br><br>Lütfen web arayüzünde oturum açın ve kişisel ayarlarınızdan 'ownCloud temel şifreleme modülü'ne giderek 'eski oturum parolası' alanına bu parolayı girdikten sonra şifreleme parolanızı ve mevcut oturum açma parolanızı güncelleyin.<br><br>",
    "Enable recovery key" : "Kurtarma anahtarını etkinleştir",
    "Disable recovery key" : "Kurtarma anahtarını devre dışı bırak",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kurtarma anahtarı, dosyaların şifrelenmesi için daha fazla \nşifreleme sunar. Bu kullanıcının dosyasının şifresini unuttuğunda kurtarmasına imkan verir.",
    "Recovery key password" : "Kurtarma anahtarı parolası",
    "Repeat recovery key password" : "Kurtarma anahtarı parolasını yineleyin",
    "Change recovery key password:" : "Kurtarma anahtarı parolasını değiştir:",
    "Old recovery key password" : "Eski kurtarma anahtarı parolası",
    "New recovery key password" : "Yeni kurtarma anahtarı parolası",
    "Repeat new recovery key password" : "Yeni kurtarma anahtarı parolasını yineleyin",
    "Change Password" : "Parola Değiştir",
    "ownCloud basic encryption module" : "ownCloud basit şifreleme modülü",
    "Your private key password no longer matches your log-in password." : "Özel anahtar parolanız artık oturum açma parolanız ile eşleşmiyor.",
    "Set your old private key password to your current log-in password:" : "Eski özel anahtar parolanızı, geçerli oturum açma parolanız olarak ayarlayın:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Eğer eski parolanızı hatırlamıyorsanız, yöneticinizden dosyalarınızı kurtarmasını talep edebilirsiniz.",
    "Old log-in password" : "Eski oturum açma parolası",
    "Current log-in password" : "Geçerli oturum açma parolası",
    "Update Private Key Password" : "Özel Anahtar Parolasını Güncelle",
    "Enable password recovery:" : "Parola kurtarmayı etkinleştir:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Bu seçeneği etkinleştirmek, parola kaybı durumunda şifrelenmiş dosyalarınıza erişimi yeniden kazanmanızı sağlayacaktır",
    "Enabled" : "Etkin",
    "Disabled" : "Devre Dışı",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Selam,\n\nSistem yöneticisi sunucu tarafında şifrelemeyi etkinleştirdi. Dosyalarınız '%s' parolası kullanılarak şifrelendi.\n\nLütfen web arayüzünde oturum açın ve kişisel ayarlarınızdan 'ownCloud temel şifreleme modülü'ne giderek 'eski oturum parolası' alanına bu parolayı girdikten sonra şifreleme parolanızı ve mevcut oturum açma parolanızı güncelleyin.\n\n",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Selam,\n\nSistem yöneticisi sunucu tarafında şifrelemeyi etkinleştirdi. Dosyalarınız '%s' parolası kullanılarak şifrelendi.\n\nLütfen web arayüzünde oturum açın ve kişisel ayarlarınızdan 'ownCloud temel şifreleme modülü'ne giderek 'eski oturum parolası' alanına bu parolayı girdikten sonra şifreleme parolanızı ve mevcut oturum açma parolanızı güncelleyin.\n\n"
},
"nplurals=2; plural=(n > 1);");
